package net.knarcraft.playerpayouts.command;

import net.knarcraft.knarlib.formatting.StringFormatter;
import net.knarcraft.playerpayouts.PlayerPayouts;
import net.knarcraft.playerpayouts.config.Configuration;
import net.knarcraft.playerpayouts.config.Translatable;
import net.knarcraft.playerpayouts.util.PlayerIdHelper;
import net.knarcraft.playerpayouts.util.StringHelper;
import org.bukkit.Bukkit;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.jetbrains.annotations.NotNull;

import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * A command for overriding payments for specific players
 */
public class SetPlayerPaymentCommand implements CommandExecutor {

    private final Configuration configuration;

    /**
     * Instantiates a new set player payment command
     *
     * @param configuration <p>The configuration to use</p>
     */
    public SetPlayerPaymentCommand(@NotNull Configuration configuration) {
        this.configuration = configuration;
    }

    @Override
    public boolean onCommand(@NotNull CommandSender commandSender, @NotNull Command command, @NotNull String s,
                             @NotNull String[] arguments) {
        StringFormatter stringFormatter = PlayerPayouts.getStringFormatter();

        // Display all current group payment overrides
        if (arguments.length == 0) {
            StringBuilder builder = new StringBuilder(stringFormatter.getUnformattedColoredMessage(
                    Translatable.CURRENT_PAYOUT_OVERRIDE));
            for (Map.Entry<UUID, Double> entry : configuration.getPlayerPayouts().entrySet()) {
                if (entry.getValue() == null) {
                    continue;
                }

                String playerName = entry.getKey().toString();
                String possibleName = Bukkit.getOfflinePlayer(entry.getKey()).getName();
                if (possibleName != null) {
                    playerName = possibleName;
                }
                builder.append(stringFormatter.replacePlaceholders(Translatable.PAYOUT_OVERRIDE_LIST_FORMAT,
                        List.of("{subject}", "{value}"), List.of(playerName, String.valueOf(entry.getValue()))));
            }
            stringFormatter.displaySuccessMessage(commandSender, builder.toString());
            return true;
        }

        String playerName = arguments[0];

        // Parse the player id
        UUID playerId = PlayerIdHelper.getId(playerName);
        if (playerId == null) {
            stringFormatter.displayErrorMessage(commandSender, Translatable.PLAYER_ID_REQUIRED);
            return false;
        }

        // Display the specified group's payment override
        if (arguments.length == 1) {
            String output = stringFormatter.getUnformattedMessage(Translatable.CURRENT_PAYOUT_OVERRIDE);
            Double value = configuration.getPlayerPayout(playerId);
            if (value != null) {
                output += stringFormatter.replacePlaceholders(Translatable.PAYOUT_OVERRIDE_LIST_FORMAT,
                        List.of("{subject}", "{value}"), List.of(playerName, String.valueOf(value)));
            }
            stringFormatter.displaySuccessMessage(commandSender, output);
            return true;
        }

        // Parse the payout value
        try {
            if (StringHelper.isNonValue(arguments[1])) {
                configuration.setPlayerPayout(playerId, null);
                stringFormatter.displaySuccessMessage(commandSender, stringFormatter.replacePlaceholder(
                        Translatable.PLAYER_PAYOUT_CLEARED, "{player}", playerName));
            } else {
                Double payout = Double.parseDouble(arguments[1]);
                configuration.setPlayerPayout(playerId, payout);
                stringFormatter.displaySuccessMessage(commandSender, stringFormatter.replacePlaceholders(
                        Translatable.PLAYER_PAYOUT_SET, List.of("{player}", "{value}"),
                        List.of(playerName, String.valueOf(payout))));
            }
            return true;
        } catch (NumberFormatException exception) {
            stringFormatter.displayErrorMessage(commandSender, Translatable.PAYOUT_NUMBER_REQUIRED);
            return false;
        }
    }

}
