package net.knarcraft.playerpayouts.config.payout;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * Delimiters usable in the payout setting string
 */
public enum PayoutDelimiter {

    /**
     * Add a payout component to another
     */
    ADD('+'),

    /**
     * Choose one if possible, and the other if not
     */
    OR(','),
    ;

    private final Character character;

    /**
     * Instantiates a new payout delimiter
     *
     * @param character <p>The character used to specify the delimiter</p>
     */
    PayoutDelimiter(@NotNull Character character) {
        this.character = character;
    }

    /**
     * Tries to match the payout delimiter specified
     *
     * @param toMatch <p>The character to match to a payout delimiter</p>
     * @return <p>The matched delimiter, or null if a match was not found</p>
     */
    public static @Nullable PayoutDelimiter match(@NotNull Character toMatch) {
        for (PayoutDelimiter payoutDelimiter : PayoutDelimiter.values()) {
            if (payoutDelimiter.character.equals(toMatch)) {
                return payoutDelimiter;
            }
        }
        return null;
    }

}
