package net.knarcraft.playerpayouts.config.payout;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;

/**
 * Components used to specify a payout mode
 */
public enum PayoutTarget implements PayoutComponent {

    /**
     * The payout set for the specific player
     */
    PLAYER(List.of("p", "player")),

    /**
     * The payout of all of a player's groups
     */
    GROUPS(List.of("g", "group", "groups")),

    /**
     * The payout of a player's highest group
     */
    HIGHEST_GROUP(List.of("hg", "highestGroup")),

    /**
     * The base payout
     */
    BASE(List.of("b", "base")),
    ;

    private final List<String> stringRepresentations;

    /**
     * Instantiates a new payout component
     *
     * @param stringRepresentations <p>The possible string representations of the payout component</p>
     */
    PayoutTarget(List<String> stringRepresentations) {
        this.stringRepresentations = stringRepresentations;
    }

    /**
     * Tries to find a payout component matching the given string
     *
     * @param toMatch <p>A string that specifies a payout component</p>
     * @return <p>The payout component matching the input, or null if no match was found</p>
     */
    public static @Nullable PayoutTarget match(@NotNull String toMatch) {
        for (PayoutTarget payoutTarget : PayoutTarget.values()) {
            for (String representation : payoutTarget.stringRepresentations) {
                if (representation.equalsIgnoreCase(toMatch)) {
                    return payoutTarget;
                }
            }
        }
        return null;
    }

}
