package net.knarcraft.playerpayouts.util;

import org.bukkit.Bukkit;
import org.bukkit.OfflinePlayer;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.UUID;

/**
 * A helper class for dealing with player ids
 */
public final class PlayerIdHelper {

    private PlayerIdHelper() {

    }

    /**
     * Gets a player's UUID from the player's identifier
     *
     * @param playerIdentifier <p>The identifier of the player</p>
     * @return <p>The id of the player, or null if an invalid UUID or name has been given</p>
     */
    public static @Nullable UUID getId(@NotNull String playerIdentifier) {
        UUID playerId;
        try {
            // Find player from UUID
            playerId = UUID.fromString(playerIdentifier);
        } catch (IllegalArgumentException exception) {
            // Get player from player name
            Player player = Bukkit.getPlayer(playerIdentifier);
            if (player != null) {
                playerId = player.getUniqueId();
            } else {
                // Try to match the player name against the offline player list
                playerId = null;
                for (OfflinePlayer offlinePlayer : Bukkit.getOfflinePlayers()) {
                    if (offlinePlayer.getName() != null && offlinePlayer.getName().equals(playerIdentifier)) {
                        playerId = offlinePlayer.getUniqueId();
                    }
                }

                if (playerId == null) {
                    return null;
                }
            }
        }

        return playerId;
    }

}
